from policyengine_it.model_api import *


class household_refundable_tax_credits(Variable):
    value_type = float
    entity = Household
    label = "refundable tax credits"
    definition_period = YEAR
    unit = EUR
    adds = ["refundable_tax_credits"]
